# PolicyParrot
PolicyParrot aims to provide a light guidance in coding RL algorithms. It doesn't expect you to code RL from scratch, but equally it doesn't confuse you with lots of inheritance.

- PolicyParrot doesn't confuse and allows flexibility - classes are totally flat,
- PolicyParrot encourages standardisation across algorithms - all SOTA algorithms follow PolicyParrot's class schemas.

![Diagram showing that PolicyParrot aims to minimise how difficult it can be to implement RL algorithms](./charter.png)